/* Copyright (c) 1996 University of Utah.  All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for NON-COMMERCIAL purposes and without fee is
 * hereby granted provided that this copyright notice appears in all
 * copies.
 *
 * See http://www.cs.utah.edu/~hamlet for more educational resources.
 *
 * The University of Utah MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT
 * THE SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR
 * NON-INFRINGEMENT. The University of Utah SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */


/*
<applet
    code="hamlet.AppButton.class"
    codebase=".."
    name="Robot.Robot" 
    width=150 height=25 align=absbottom>
    <param name=LABEL value="Launch Robot Window">
        If you can read this, you don't need glasses.  But you do <br>
        need a Java-compatible browser.<br>
</applet>
*/


/* 
 *      FileName:       Robot.java
 *      Written by:     Brandon Harvey
 *      Date:           June 1996
 *
 *      Modified by:	Elizabeth Odekirk
 *      Date:		October 1996
 */ 
package Robot;

import java.awt.*;
import hamlet.*;
import Robot.*;

public class Robot extends AppFrame  {
  
  //  Interface components
  robotControls	northPanel;
  robotPanel	thePanel;
  MenuItem	liftItem, haltItem;
  
public Robot() {
	setTitle("Robot Weightlifting");
    setLayout( new BorderLayout( 10,10 ) );

    //  set up menus
    MenuBar menubar = getMenuBar();
    Menu robotMenu = new Menu("Robot");
    robotMenu.add( liftItem = new MenuItem("Lift") );
    robotMenu.add( haltItem = new MenuItem("Halt") );
    menubar.add( robotMenu );
    
    add("North", northPanel = new robotControls() );
    add("Center", thePanel = new robotPanel() );
    thePanel.controlPanel = northPanel;
    
    setHelpText();
  }
  
private void setHelpText() {
    helpText = 
      
	"This applet demonstrates an animated, labeled version of \n"	+
	"the squatting robotic weightlifter which is described in\n"	+
	"Chaper 11 of \"Introduction to Scientific Programming\" by\n"	+
	"Joseph L. Zachary.\n\n"					+
	"File Menu\n"							+
	"   + Reset: Returns to the default plot region\n"		+
	"   + Refresh: Refreshes the applet\n"				+
	"   + Hide: Removes the applet from the display\n"		+
	"   + Quit: Terminates the applet\n\n"				+
        //								//
	"Robot Menu\n"							+
        "   + Lift: Lifts or drops the weights until the knee angle\n"	+ 
	"     of the robot is the same as that specified in the\n"	+
	"     Knee Angle input field\n"					+
        "   + Halt: Halts the robot's lift (or drop).  This resets the\n"+
	"     Knee Angle input field to the knee\'s current angle\n\n"	+ 
	//								//
        "Help Menu\n"							+
        "   + With Applet: Displays this help dialog\n\n"		+
	//								//
	"Input Fields\n"						+
        "   + Torso Length: The length, in millimeters, of the torso\n"	+
	"     (between the shoulder and the hip) of the robot\n"	+
	"   + Knee Angle: The angle, in degrees, of the knee\n"		+
	"     (between the thigh and the shin)\n"			+
	//								//
	"Display\n"							+
	"   + Robot: The graph shows the robot, along with related\n"	+
	"     geometry.  The red lines represent the robot.  The top\n"	+
	"     red line goes from the shoulders to the hips, the second\n"+
	"     from the hips to the knees, and the third from the\n"	+
	"     knees to the feet\n"					+
	"   + Horizontal Lines: These show the current height of the\n"	+
	"     shoulders, hips, and knees\n"				+
	"   + Vertical Lines: These show the current horizontal\n"	+
	"     position of the shoulders (and feet), hips, and knees\n"	+
	"   + Green Angles: These show the angles between the torso and\n"+
	"     the thigh and the thigh and the shin\n"			+
	"   + Blue Angles: These show the angles between the torso,\n"	+
	"     thigh, and shin and the horizontal lines through, \n"	+
	"     respectively, the hip, knee, and ankle.  These\n"		+
	"     correspond to gamma, beta, and alpha in Figure 11.2\n"	+
	"";	
}

public void reset() {
  thePanel.reset();
}

public Dimension preferredSize()  {
     return new Dimension(500,450);
}

protected void handleMessage( String msg ) {
    if ( msg.equals("Lift") )
      thePanel.go();
    else if ( msg.equals("Reset") )
      thePanel.reset();
    else if ( msg.equals("Halt") )
      thePanel.halt();
    else if ( msg.equals("stand_erect") ){
      northPanel.kneeField.setIntText(180);
      thePanel.go();
    }
    else if ( msg.equals("stand_at_90") ){
      northPanel.kneeField.setIntText(90);
      thePanel.go();
    }
}
   
public boolean action(Event evt, Object arg) {
  
  if ( super.action( evt, arg ) )
    return true;
  
  if ( evt.target instanceof MenuItem ) {
    if ( evt.target.equals( liftItem ) )  {
      //System.out.println("Got a lift");
      if ( thePanel.animatorThread != null ) 
	thePanel.animatorThread.stop();
      //System.out.println("Started the Lift");
      thePanel.go();
    }
    else if ( evt.target.equals( haltItem ) ) {
      thePanel.halt();
    }
    return true;
  }  
  else return false;
}

}


